.. _how-to-env:

How to create a virtual environment
===================================

To create a virtual environment with name :code:`<name>` run::

    $ python -m venv <name>

How to activate :code:`<name>`
------------------------------

On Linux or macOS type::

    $ source env/bin/activate

On Windows type::

    $ env\Scripts\activate
